@@ -20,7 +20,8 @@ class BaseMuckRockClient(object):
 
     def _get_request(self, url, params, headers={}):
         headers.update({'User-Agent': self.USER_AGENT})
-        return requests.get(url, params=params, headers=headers).json()
+        r = requests.get(url, params=params, headers=headers)
+        return r.json()
 
 
 class MuckRock(BaseMuckRockClient):
@@ -50,7 +51,9 @@ class FoiaClient(BaseMuckRockClient):
         embargo=None,
         jurisdiction=None,
         agency=None,
-        page_size=100
+        has_datetime_submitted=None,
+        has_datetime_done=None,
+        ordering="-datetime_submitted",
     ):
         params = {}
         if user:
@@ -65,5 +68,17 @@ class FoiaClient(BaseMuckRockClient):
             params['jurisdiction'] = jurisdiction
         if user:
             params['agency'] = agency
-        params['page_size'] = page_size
+        datetime_submitted_choices = {
+            None: 1,
+            True: 2,
+            False: 3,
+        }
+        params['has_datetime_submitted'] = datetime_submitted_choices[has_datetime_submitted]
+        datetime_done_choices = {
+            None: 1,
+            True: 2,
+            False: 3,
+        }
+        params['has_datetime_done'] = datetime_done_choices[has_datetime_done]
+        params['ordering'] = ordering
         return self._get_request(self.BASE_URI + self.endpoint, params)['results']
